.. image:: pk1/static/logo-large.png
    :width: 200
    :alt: Logo

===================
Introduction
===================
PackOne, inspired by the "serverless" trend in cloud computing and big data processing, has the ambitions to bridge the IaaS to Apache Ambari seamlessly and coordinate Ambari Services into a high-level workspace. 

===================
Install
===================
pip install pk1


===================
Acknowledge
===================
National key Research Program of China: Scientific Big Data Management System (No.2016YFB1000600)